==> kbarcode-trinity_3.5.13.2.orig.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/textitem.h <==
/***************************************************************************
                         textitem.h  -  description
                             -------------------
    begin                : Do Sep 2 2004
    copyright            : (C) 2004 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
                                                                          
    This program is free software; you can redistribute it and/or modify  
    it under the terms of the GNU General Public License as published by  
    the Free Software Foundation; either version 2 of the License, or     
    (at your option) any later version.                                   
                                                                          
 ***************************************************************************/

#ifndef TEXTITEM_H
#define TEXTITEM_H
#include <tqstring.h>
#include "documentitem.h"

class LabelEditor;

/**
 * Class TextItem
 * Formated rich text (drawn using either DSRichText or TQSimpleRichText - once it is bug free) on screen or printer.
 */
class TextItem : public DocumentItem {
public:
    TextItem ();
        
    void draw (TQPainter* painter);
    void drawZpl( TQTextStream* stream );
    void drawIpl( TQTextStream* stream, IPLUtils* utils );
    void drawEPcl( TQTextStream* stream );
    
    int  rtti () const { return eRtti_Text; }

    void  loadXML (TQDomElement* element);
    void  saveXML (TQDomElement* element);
    
    void  setText (const TQString & text);
    TQString  text () const;

    inline void setRotation( double rot ) { m_rotation = rot; }
    inline double rotation() const { return m_rotation; }

    static bool IsTQtTextRenderingBroken();
private:
    void init();
    
private:
    static bool s_qt_broken;
    static bool s_qt_broken_init;

    double m_rotation;
    TQString m_text;
};
#endif //TEXTITEM_H

==> kbarcode-trinity_14.1.3.orig.tar.xz: kbarcode-trinity-14.1.3/kbarcode/textitem.h <==
/***************************************************************************
                         textitem.h  -  description
                             -------------------
    begin                : Do Sep 2 2004
    copyright            : (C) 2004 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
                                                                          
    This program is free software; you can redistribute it and/or modify  
    it under the terms of the GNU General Public License as published by  
    the Free Software Foundation; either version 2 of the License, or     
    (at your option) any later version.                                   
                                                                          
 ***************************************************************************/

#ifndef TEXTITEM_H
#define TEXTITEM_H
#include <tqstring.h>
#include "documentitem.h"

class LabelEditor;

/**
 * Class TextItem
 * Formated rich text (drawn using TQSimpleRichText) on screen or printer.
 */
class TextItem : public DocumentItem {
public:
    TextItem ();
        
    void draw (TQPainter* painter);
    void drawZpl( TQTextStream* stream );
    void drawIpl( TQTextStream* stream, IPLUtils* utils );
    void drawEPcl( TQTextStream* stream );
    
    int  rtti () const { return eRtti_Text; }

    void  loadXML (TQDomElement* element);
    void  saveXML (TQDomElement* element);
    
    void  setText (const TQString & text);
    TQString  text () const;

    inline void setRotation( double rot ) { m_rotation = rot; }
    inline double rotation() const { return m_rotation; }

private:
    void init();
    
private:
    double m_rotation;
    TQString m_text;
};
#endif //TEXTITEM_H
